@@ -3,6 +3,7 @@
 use strict;
 
 use Graphics::Framebuffer;
+use List::Util qw(min max);
 
 $| = 1;
 system('clear');
@@ -25,8 +26,8 @@ my $xm            = 1920 / $F->{'XRES'};
 my $ym            = 1080 / $F->{'YRES'};
 my $XX            = $screen_width;
 my $YY            = $screen_height;
-my $center_x      = int(960 * $xm);
-my $center_y      = int(540 * $ym);
+my $center_x      = $XX / 2;
+my $center_y      = $YY / 2;
 my $factor        = 5;
 
 $F->cls('OFF');
@@ -41,23 +42,23 @@ while (time < $s) {
 }
 
 print_it($F, 'Line Test');
-for (my $l = 40 ; $l < $YY ; $l += 40) {
+for (my $l = $F->{'Y_CLIP'} ; $l < $YY ; $l += 4) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->line({'x' => 0, 'y' => $l, 'xx' => $XX, 'yy' => $l});
 
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->line({'x' => 0, 'y' => $l, 'xx' => $l, 'yy' => 40});
+    $F->line({'x' => 0, 'y' => $l, 'xx' => $l, 'yy' => $F->{'Y_CLIP'}});
 
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->line({'x' => $XX, 'y' => $l, 'xx' => $XX - $l, 'yy' => 40});
+    $F->line({'x' => $XX, 'y' => $l, 'xx' => $XX - $l, 'yy' => $F->{'Y_CLIP'}});
     
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->line({'x' => $XX, 'y' => $YY - $l, 'xx' => $XX - $l, 'yy' => 40});
+    $F->line({'x' => $XX, 'y' => $YY - $l, 'xx' => $XX - $l, 'yy' => $F->{'Y_CLIP'}});
 
 } ## end for (my $l = 40 ; $l < ...)
-for (my $l = 0 ; $l < $XX ; $l += 40) {
+for (my $l = 0 ; $l < $XX ; $l += 4) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->line({'x' => $l, 'y' => 40, 'xx' => $l, 'yy' => $YY});
+    $F->line({'x' => $l, 'y' => $F->{'Y_CLIP'}, 'xx' => $l, 'yy' => $YY});
 }
 
 print_it($F, 'Box Test');
@@ -190,7 +191,7 @@ while (time < $s) {
     $F->arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y),'start_degrees' => rand(360),'end_degrees' => rand(360)});
 }
 
-print_it($F, 'Filled Circle Test');
+print_it($F, 'Poly Arc Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
@@ -322,45 +323,53 @@ while (time < $s) {
     $F->bezier({'coordinates' => \@coords, 'points' => 100});
 } ## end foreach my $z (1 .. (40 * $factor...))
 
-print_it($F, 'Testing TrueType Font Rendering (random height/width)');
+if ($XX > 255) {
+    print_it($F, 'Testing TrueType Font Rendering (random height/width)');
 
-for (my $c = 8 ; $c < 400 ; $c += (20 * $factor)) {
-    my $x  = int(rand(600 * $xm));
-    my $y  = int(rand(900 * $ym));
-    my $h  = int(rand(300 * $ym)) + 8;
-    my $ws = rand(4);
+    for (my $c = 8 ; $c < 400 ; $c += (20 * $factor)) {
+        my $x  = int(rand(600 * $xm));
+        my $y  = int(rand(900 * $ym));
+        my $h  = int(rand(300 * $ym));
+        my $ws = rand(4);
     
-    my $b = $F->ttf_print(
-        {
-            'x'            => $x,
-              'y'            => $y,
-              'height'       => $c * $ym,
-              'wscale'       => $ws,
-              'color'        => sprintf('%x%x%x%x', int(rand(256)), int(rand(256)), int(rand(256)), 255),
-              'text'         => 'GFB',
-              'bounding_box' => 1,
-              'center'       => 3
+        my $b = $F->ttf_print(
+            {
+                'x'            => $x,
+                  'y'            => $y,
+                  'height'       => $c * $ym,
+                  'wscale'       => $ws,
+                  'color'        => sprintf('%x%x%x%x', int(rand(256)), int(rand(256)), int(rand(256)), 255),
+                  'text'         => 'GFB',
+                  'bounding_box' => 1,
+                  'center'       => 3
+            }
+        );
+        if (defined($b)) {
+            $b->{'x'} = rand($F->{'XX_CLIP'} - $b->{'pwidth'});
+            $F->ttf_print($b);
         }
-    );
-    if (defined($b)) {
-        $b->{'x'} = rand($F->{'XX_CLIP'} - $b->{'pwidth'});
-        $F->ttf_print($b);
     }
 }
-
 print_it($F, 'Testing flood fill');
-$F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-$F->polygon({'coordinates' => [220 * $xm, 190 * $ym, 1520 * $xm, 80 * $xm, 1160 * $xm, $YY, 960 * $xm, 540 * $ym, 760 * $xm, 1080 * $ym]});
-$F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-$F->polygon({'coordinates' => [1270 * $xm, 570 * $ym, 970 * $xm, 170 * $ym, 600 * $xm, 500 * $ym]});
-$F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-$F->circle({'x' => 500 * $xm, 'y' => 320 * $ym, 'radius' => 100 * $xm});
-
-$F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-$F->fill({'x' => 240 * $xm, 'y' => 200 * $ym});
-
-$F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-$F->fill({'x' => 960 *$xm, 'y' => 440 * $ym});
+if ($XX > 255) {
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->polygon({'coordinates' => [220 * $xm, 190 * $ym, 1520 * $xm, 80 * $xm, 1160 * $xm, $YY, 960 * $xm, 540 * $ym, 760 * $xm, 1080 * $ym]});
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->polygon({'coordinates' => [1270 * $xm, 570 * $ym, 970 * $xm, 170 * $ym, 600 * $xm, 500 * $ym]});
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->circle({'x' => 500 * $xm, 'y' => 320 * $ym, 'radius' => 100 * $xm});
+    
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->fill({'x' => 240 * $xm, 'y' => 200 * $ym});
+    
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->fill({'x' => 960 *$xm, 'y' => 440 * $ym});
+} else {
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->polygon({'coordinates' => [$center_x,3, 3,$YY - 3, $center_x,$center_y, $XX - 3,$YY - 4]});
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->fill({'x' => 3, 'y' => 3});
+}
 
 print_it($F, 'Testing Color Replace (clipping on)');
 
@@ -436,6 +445,8 @@ my $image = $F->load_image(
     {
         'x'    => 0,
           'y'    => 0,
+          'width' => min(640,$XX/2),
+          'height' => min(405,$YY/2),
           'file' => 'examples/RWBY_Faces.png'
     }
 );
@@ -457,23 +468,27 @@ sub print_it {
     $fb->normal_mode();
     $fb->clip_reset();
     $fb->cls();
-    $fb->or_mode();
+    unless ($XX < 256) {
+        $fb->or_mode();
 
-    my $b = $fb->ttf_print(
-        {
-            'x'            => 5  * $xm,
-            'y'            => 30 * $ym,
-            'height'       => 30 * $ym,
-            'color'        => '00FF00',
-            'text'         => $message,
-            'bounding_box' => 1,
-            'center'       => 0,
-            'antialias'    => 1
-        }
-    );
-    $fb->ttf_print($b);
-    $fb->clip_set({'x' => 0, 'y' => $b->{'pheight'}, 'xx' => $XX, 'yy' => $YY});
-    $fb->normal_mode();
+        my $b = $fb->ttf_print(
+            {
+                'x'            => 5  * $xm,
+                'y'            => 30 * $ym,
+                'height'       => 30 * $ym,
+                'color'        => '00FF00',
+                'text'         => $message,
+                'bounding_box' => 1,
+                'center'       => 0,
+                'antialias'    => 1
+            }
+        );
+        $fb->ttf_print($b);
+        $fb->clip_set({'x' => 0, 'y' => $b->{'pheight'}, 'xx' => $XX, 'yy' => $YY});
+        $fb->normal_mode();
+    } else {
+        print "$message\n";
+    }
 } ## end sub print_it
 
 __END__
